==> 1.2.2.tar.gz: paim-on/README.md <==
# Paimon Launcher

Alternative launcher for GI, installs and updates the game, handles patches automatically. It's developed to run under Linux only.

Download manager Aria2c is used for improved download speed.


![Updating the game](https://notabug.org/loentar/paimon-launcher/raw/master/screenshots/updating.png)


### Usage

At start the launcher tries to detect game installation by looking in few common directories. If you have game installed but launcher didn't detected its installation path, click "Browse..." and choose the "Game" directory (where UnityPlayer.dll is located).

If you don't have game installed, launcher will offer to install it to default directory. Click "Browse..." if you wish to install to the different directory.


### Installation

Pre-requirements: For deb systems run: `sudo apt install git`



This app is distributed via AppImage.

0. Download the latest archive from [Releases](https://notabug.org/loentar/paimon-launcher/releases)
0. Open Terminal
0. `cd ~/Downloads`
0. `chmod +x Paimon_Launcher-[VERSION]-x86_64.AppImage`
0. `./Paimon_Launcher-[VERSION]-x86_64.AppImage`

or read [this article](https://codeburst.io/how-to-install-and-run-appimage-on-linux-systems-f031ec6a85ce) to learn how to do the same from GUI.

This launcher is built on Ubuntu 16.04 and tested on Ubuntu 16.04, 20.04. Other distributions should be supported as well. If you face a bug feel free to [fill an issue](https://notabug.org/loentar/paimon-launcher/issues/new).


### Build from sources

If provided AppImage doesn't work for some reason you may build launcher from source code:

0. Make sure build dependencies are installed. For deb systems run: `sudo apt install build-essential git`
0. Clone this project using: `git clone https://notabug.org/loentar/paimon-launcher.git`
0. Download and start https://www.qt.io/download-thank-you .
0. You need to `chmod +x qt-unified-linux-x64-*-online.run` to start it.
0. Register/sign in with free Qt account.
0. Install version 5.15.2 of Qt only desktop (Desktop gcc 64-bit 5.15.2-0-....), you don't need any other packages to build this project.
0. After Qt installation is finished, start Qt Creator and open `paimon-launcher.pro` from cloned directory
0. Set up everything by default (Desktop 5.15.2)
0. Choose target Release (Ctrl+T, Release) else updater will not be able to update Web version
0. Build and run the project (Ctrl+R or the green triangle icon to the left bottom side)


### Command line option configuration

You can configure launcher to use Lutris/Proton instead of default wine installation also to control launch options and environment. To make this possible the file `$HOME/.local/share/paimon-launcher/wineconfig.sh` is provided. It will appear after you press "Start" at the first time. As workaround to create this file before start, choose "kill wine server" from settings menu.


### Known bugs and Workarounds

Fedora 34:

Launcher UI doesn't update client:
```
Failed to download file
Error updating client
```

When started from Terminal:
```
[ERROR] Failed to load trusted CA certificates from /etc/ssl/certs/ca-certificates.crt. Cause: Error while reading file.\n"
```

Problem related with aria2c and CRT. 

Workaround:
```
sudo ln -s /etc/ssl/certs/ca-bundle.crt /etc/ssl/certs/ca-certificates.crt
```



### TODO

 - Check for launcher updates and open new release page.
 - Show progress+status icon like gparted does.
 - Detect Wine, Lutris, Proton versions, make it possible to select specific version from settings.

==> 1.2.3.tar.gz: paim-on/README.md <==
# Paimon Launcher

Alternative launcher for GI, installs and updates the game, handles patches automatically. It's developed to run under Linux only.

Download manager Aria2c is used for improved download speed.


![Updating the game](https://notabug.org/loentar/paimon-launcher/raw/master/screenshots/updating.png)


### Usage

At start the launcher tries to detect game installation by looking in few common directories. If you have game installed but launcher didn't detected its installation path, click "Browse..." and choose the "Game" directory (where UnityPlayer.dll is located).

If you don't have game installed, launcher will offer to install it to default directory. Click "Browse..." if you wish to install to the different directory.


### Installation


This app is distributed via AppImage.

0. Download the latest archive from [Releases](https://notabug.org/loentar/paimon-launcher/releases)
0. Open Terminal
0. `cd ~/Downloads`
0. `chmod +x Paimon_Launcher-[VERSION]-x86_64.AppImage`
0. `./Paimon_Launcher-[VERSION]-x86_64.AppImage`

or read [this article](https://codeburst.io/how-to-install-and-run-appimage-on-linux-systems-f031ec6a85ce) to learn how to do the same from GUI.

This launcher is built on Ubuntu 16.04 and tested on Ubuntu 16.04, 20.04, Fedora 34. Other distributions should be supported as well. If you face a bug feel free to [file an issue](https://notabug.org/loentar/paimon-launcher/issues/new).


### Build from sources

If provided AppImage doesn't work for some reason you may build launcher from source code:

0. Make sure build dependencies are installed. For deb systems run: `sudo apt install build-essential git`
0. Clone this project using: `git clone https://notabug.org/loentar/paimon-launcher.git`
0. Download and start https://www.qt.io/download-thank-you .
0. You need to `chmod +x qt-unified-linux-x64-*-online.run` to start it.
0. Register/sign in with free Qt account.
0. Install version 5.15.2 of Qt only desktop (Desktop gcc 64-bit 5.15.2-0-....), you don't need any other packages to build this project.
0. After Qt installation is finished, start Qt Creator and open `paimon-launcher.pro` from cloned directory
0. Set up everything by default (Desktop 5.15.2)
0. Choose target Release (Ctrl+T, Release) else updater will not be able to update Web version
0. Build and run the project (Ctrl+R or the green triangle icon to the left bottom side)


### Command line option configuration

You can configure launcher to use Lutris/Proton instead of default wine installation also to control launch options and environment. To make this possible the file `$HOME/.local/share/paimon-launcher/wineconfig.sh` is provided. It will appear after you press "Start" at the first time. As workaround to create this file before start, choose "kill wine server" from settings menu.



### TODO

 - Check for launcher updates and open new release page.
 - Show progress+status icon like gparted does.
 - Detect Wine, Lutris, Proton versions, make it possible to select specific version from settings.
